@@ -82,45 +82,6 @@ class ProjectUpdate(task_manager.Task):
         return client._project_manager.update(**self.args)
 
 
-class FlavorList(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.flavors.list(**self.args)
-
-
-class FlavorCreate(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.flavors.create(**self.args)
-
-
-class FlavorDelete(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.flavors.delete(**self.args)
-
-
-class FlavorGet(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.flavors.get(**self.args)
-
-
-class FlavorListAccess(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.flavor_access.list(**self.args)
-
-
-class FlavorAddAccess(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.flavor_access.add_tenant_access(
-            **self.args
-        )
-
-
-class FlavorRemoveAccess(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.flavor_access.remove_tenant_access(
-            **self.args
-        )
-
-
 class ServerList(task_manager.Task):
     def main(self, client):
         return client.nova_client.servers.list(**self.args)
